PDFView class

Inheritance

Constructors

PDFView({Key? key, String? filePath, Uint8List? pdfData, PDFViewCreatedCallback? onViewCreated, RenderCallback? onRender, PageChangedCallback? onPageChanged, ErrorCallback? onError, PageErrorCallback? onPageError, LinkHandlerCallback? onLinkHandler, Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers, bool enableSwipe = true, bool swipeHorizontal = false, String? password, bool nightMode = false, bool autoSpacing = true, bool pageFling = true, bool pageSnap = true, bool fitEachPage = true, int defaultPage = 0, FitPolicy fitPolicy = FitPolicy.WIDTH, bool preventLinkNavigation = false})

Properties

autoSpacing → bool
final
defaultPage → int
final
enableSwipe → bool
final
filePath → String?
The initial URL to load.
final
fitEachPage → bool
final
fitPolicy → FitPolicy
final
gestureRecognizers → Set<Factory<OneSequenceGestureRecognizer>>?
Which gestures should be consumed by the pdf view.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nightMode → bool
final
onError → ErrorCallback?
final
onLinkHandler → LinkHandlerCallback?
final
onPageChanged → PageChangedCallback?
final
onPageError → PageErrorCallback?
final
onRender → RenderCallback?
final
onViewCreated → PDFViewCreatedCallback?
If not null invoked once the web view is created.
final
pageFling → bool
final
pageSnap → bool
final
password → String?
final
pdfData → Uint8List?
final
preventLinkNavigation → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swipeHorizontal → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _PDFViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited